@@ -148,7 +148,9 @@ def show_sets_filter(response):
             entrant2_chars = []
             game_winners_ids = []
             for game in node['games']:
-                if (node['slots'][0]['entrant']['id'] == game['selections'][0]['entrant']['id']):
+                if (game['selections'] is None): # This fixes an issue with selections being none while games are reported
+                    continue
+                elif (node['slots'][0]['entrant']['id'] == game['selections'][0]['entrant']['id']):
                     entrant1_chars.append(game['selections'][0]['selectionValue'])
                     entrant2_chars.append(game['selections'][1]['selectionValue'])
                 else:
